ApplicationInfo class

Information about an application.

Constructors

ApplicationInfo({String? applicationId, String? applicationName, ComputePlatform? computePlatform, DateTime? createTime, String? gitHubAccountName, bool? linkedToGitHub})
ApplicationInfo.fromJson(Map<String, dynamic> json)
factory

Properties

applicationId → String?
The application ID.
final
applicationName → String?
The application name.
final
computePlatform → ComputePlatform?
The destination platform type for deployment of the application (Lambda or Server).
final
createTime → DateTime?
The time at which the application was created.
final
gitHubAccountName → String?
The name for a connection to a GitHub account.
final
hashCode → int
The hash code for this object.
no setterinherited
linkedToGitHub → bool?
True if the user has authenticated with GitHub for the specified application. Otherwise, false.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited