BatchGetApplicationRevisionsOutput class

Represents the output of a BatchGetApplicationRevisions operation.

Constructors

BatchGetApplicationRevisionsOutput({String? applicationName, String? errorMessage, List<RevisionInfo>? revisions})
BatchGetApplicationRevisionsOutput.fromJson(Map<String, dynamic> json)
factory

Properties

applicationName → String?
The name of the application that corresponds to the revisions.
final
errorMessage → String?
Information about errors that might have occurred during the API call.
final
hashCode → int
The hash code for this object.
no setterinherited
revisions → List<RevisionInfo>?
Additional information about the revisions, including the type and location.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited