BatchGetDeploymentGroupsOutput class

Represents the output of a BatchGetDeploymentGroups operation.

Constructors

BatchGetDeploymentGroupsOutput({List<DeploymentGroupInfo>? deploymentGroupsInfo, String? errorMessage})
BatchGetDeploymentGroupsOutput.fromJson(Map<String, dynamic> json)
factory

Properties

deploymentGroupsInfo → List<DeploymentGroupInfo>?
Information about the deployment groups.
final
errorMessage → String?
Information about errors that might have occurred during the API call.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited