BatchGetDeploymentTargetsOutput class

Constructors

BatchGetDeploymentTargetsOutput({List<DeploymentTarget>? deploymentTargets})
BatchGetDeploymentTargetsOutput.fromJson(Map<String, dynamic> json)
factory

Properties

deploymentTargets → List<DeploymentTarget>?
A list of target objects for a deployment. Each target object contains details about the target, such as its status and lifecycle events. The type of the target objects depends on the deployment' compute platform.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited