DeploymentConfigInfo class

Information about a deployment configuration.

Constructors

DeploymentConfigInfo({ComputePlatform? computePlatform, DateTime? createTime, String? deploymentConfigId, String? deploymentConfigName, MinimumHealthyHosts? minimumHealthyHosts, TrafficRoutingConfig? trafficRoutingConfig})
DeploymentConfigInfo.fromJson(Map<String, dynamic> json)
factory

Properties

computePlatform → ComputePlatform?
The destination platform type for the deployment (Lambda, Server, or ECS).
final
createTime → DateTime?
The time at which the deployment configuration was created.
final
deploymentConfigId → String?
The deployment configuration ID.
final
deploymentConfigName → String?
The deployment configuration name.
final
hashCode → int
The hash code for this object.
no setterinherited
minimumHealthyHosts → MinimumHealthyHosts?
Information about the number or percentage of minimum healthy instance.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trafficRoutingConfig → TrafficRoutingConfig?
The configuration that specifies how the deployment traffic is routed. Used for deployments with a Lambda or ECS compute platform only.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited