DeploymentInfo class

Information about a deployment.

Constructors

DeploymentInfo({String? additionalDeploymentStatusInfo, String? applicationName, AutoRollbackConfiguration? autoRollbackConfiguration, BlueGreenDeploymentConfiguration? blueGreenDeploymentConfiguration, DateTime? completeTime, ComputePlatform? computePlatform, DateTime? createTime, DeploymentCreator? creator, String? deploymentConfigName, String? deploymentGroupName, String? deploymentId, DeploymentOverview? deploymentOverview, List<String>? deploymentStatusMessages, DeploymentStyle? deploymentStyle, String? description, ErrorInformation? errorInformation, String? externalId, FileExistsBehavior? fileExistsBehavior, bool? ignoreApplicationStopFailures, bool? instanceTerminationWaitTimeStarted, LoadBalancerInfo? loadBalancerInfo, RevisionLocation? previousRevision, RevisionLocation? revision, RollbackInfo? rollbackInfo, DateTime? startTime, DeploymentStatus? status, TargetInstances? targetInstances, bool? updateOutdatedInstancesOnly})
DeploymentInfo.fromJson(Map<String, dynamic> json)
factory

Properties

additionalDeploymentStatusInfo → String?
Provides information about the results of a deployment, such as whether instances in the original environment in a blue/green deployment were not terminated.
final
applicationName → String?
The application name.
final
autoRollbackConfiguration → AutoRollbackConfiguration?
Information about the automatic rollback configuration associated with the deployment.
final
blueGreenDeploymentConfiguration → BlueGreenDeploymentConfiguration?
Information about blue/green deployment options for this deployment.
final
completeTime → DateTime?
A timestamp that indicates when the deployment was complete.
final
computePlatform → ComputePlatform?
The destination platform type for the deployment (Lambda, Server, or ECS).
final
createTime → DateTime?
A timestamp that indicates when the deployment was created.
final
creator → DeploymentCreator?
The means by which the deployment was created:
final
deploymentConfigName → String?
The deployment configuration name.
final
deploymentGroupName → String?
The deployment group name.
final
deploymentId → String?
The unique ID of a deployment.
final
deploymentOverview → DeploymentOverview?
A summary of the deployment status of the instances in the deployment.
final
deploymentStatusMessages → List<String>?
Messages that contain information about the status of a deployment.
final
deploymentStyle → DeploymentStyle?
Information about the type of deployment, either in-place or blue/green, you want to run and whether to route deployment traffic behind a load balancer.
final
description → String?
A comment about the deployment.
final
errorInformation → ErrorInformation?
Information about any error associated with this deployment.
final
externalId → String?
The unique ID for an external resource (for example, a CloudFormation stack ID) that is linked to this deployment.
final
fileExistsBehavior → FileExistsBehavior?
Information about how AWS CodeDeploy handles files that already exist in a deployment target location but weren't part of the previous successful deployment.
final
hashCode → int
The hash code for this object.
no setterinherited
ignoreApplicationStopFailures → bool?
If true, then if an ApplicationStop, BeforeBlockTraffic, or AfterBlockTraffic deployment lifecycle event to an instance fails, then the deployment continues to the next deployment lifecycle event. For example, if ApplicationStop fails, the deployment continues with DownloadBundle. If BeforeBlockTraffic fails, the deployment continues with BlockTraffic. If AfterBlockTraffic fails, the deployment continues with ApplicationStop.
final
instanceTerminationWaitTimeStarted → bool?
Indicates whether the wait period set for the termination of instances in the original environment has started. Status is 'false' if the KEEP_ALIVE option is specified. Otherwise, 'true' as soon as the termination wait period starts.
final
loadBalancerInfo → LoadBalancerInfo?
Information about the load balancer used in the deployment.
final
previousRevision → RevisionLocation?
Information about the application revision that was deployed to the deployment group before the most recent successful deployment.
final
revision → RevisionLocation?
Information about the location of stored application artifacts and the service from which to retrieve them.
final
rollbackInfo → RollbackInfo?
Information about a deployment rollback.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → DateTime?
A timestamp that indicates when the deployment was deployed to the deployment group.
final
status → DeploymentStatus?
The current state of the deployment as a whole.
final
targetInstances → TargetInstances?
Information about the instances that belong to the replacement environment in a blue/green deployment.
final
updateOutdatedInstancesOnly → bool?
Indicates whether only instances that are not running the latest application revision are to be deployed to.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited