DeploymentOverview class

Information about the deployment status of the instances in the deployment.

Constructors

DeploymentOverview({int? failed, int? inProgress, int? pending, int? ready, int? skipped, int? succeeded})
DeploymentOverview.fromJson(Map<String, dynamic> json)
factory

Properties

failed → int?
The number of instances in the deployment in a failed state.
final
hashCode → int
The hash code for this object.
no setterinherited
inProgress → int?
The number of instances in which the deployment is in progress.
final
pending → int?
The number of instances in the deployment in a pending state.
final
ready → int?
The number of instances in a replacement environment ready to receive traffic in a blue/green deployment.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipped → int?
The number of instances in the deployment in a skipped state.
final
succeeded → int?
The number of instances in the deployment to which revisions have been successfully deployed.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited