DeploymentStyle class

Information about the type of deployment, either in-place or blue/green, you want to run and whether to route deployment traffic behind a load balancer.

Constructors

DeploymentStyle({DeploymentOption? deploymentOption, DeploymentType? deploymentType})
DeploymentStyle.fromJson(Map<String, dynamic> json)
factory

Properties

deploymentOption → DeploymentOption?
Indicates whether to route deployment traffic behind a load balancer.
final
deploymentType → DeploymentType?
Indicates whether to run an in-place deployment or a blue/green deployment.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited