DeploymentTarget class

Information about the deployment target.

Constructors

DeploymentTarget({CloudFormationTarget? cloudFormationTarget, DeploymentTargetType? deploymentTargetType, ECSTarget? ecsTarget, InstanceTarget? instanceTarget, LambdaTarget? lambdaTarget})
DeploymentTarget.fromJson(Map<String, dynamic> json)
factory

Properties

cloudFormationTarget → CloudFormationTarget?
final
deploymentTargetType → DeploymentTargetType?
The deployment type that is specific to the deployment's compute platform or deployments initiated by a CloudFormation stack update.
final
ecsTarget → ECSTarget?
Information about the target for a deployment that uses the Amazon ECS compute platform.
final
hashCode → int
The hash code for this object.
no setterinherited
instanceTarget → InstanceTarget?
Information about the target for a deployment that uses the EC2/On-premises compute platform.
final
lambdaTarget → LambdaTarget?
Information about the target for a deployment that uses the AWS Lambda compute platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited