Diagnostics class

Diagnostic information about executable scripts that are part of a deployment.

Constructors

Diagnostics({LifecycleErrorCode? errorCode, String? logTail, String? message, String? scriptName})
Diagnostics.fromJson(Map<String, dynamic> json)
factory

Properties

errorCode → LifecycleErrorCode?
The associated error code:
final
hashCode → int
The hash code for this object.
no setterinherited
logTail → String?
The last portion of the diagnostic log.
final
message → String?
The message associated with the error.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scriptName → String?
The name of the script.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited