ECSTarget class

Information about the target of an Amazon ECS deployment.

Constructors

ECSTarget({String? deploymentId, DateTime? lastUpdatedAt, List<LifecycleEvent>? lifecycleEvents, TargetStatus? status, String? targetArn, String? targetId, List<ECSTaskSet>? taskSetsInfo})
ECSTarget.fromJson(Map<String, dynamic> json)
factory

Properties

deploymentId → String?
The unique ID of a deployment.
final
hashCode → int
The hash code for this object.
no setterinherited
lastUpdatedAt → DateTime?
The date and time when the target Amazon ECS application was updated by a deployment.
final
lifecycleEvents → List<LifecycleEvent>?
The lifecycle events of the deployment to this target Amazon ECS application.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → TargetStatus?
The status an Amazon ECS deployment's target ECS application.
final
targetArn → String?
The Amazon Resource Name (ARN) of the target.
final
targetId → String?
The unique ID of a deployment target that has a type of ecsTarget.
final
taskSetsInfo → List<ECSTaskSet>?
The ECSTaskSet objects associated with the ECS target.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited