ErrorInformation class

Information about a deployment error.

Constructors

ErrorInformation({ErrorCode? code, String? message})
ErrorInformation.fromJson(Map<String, dynamic> json)
factory

Properties

code → ErrorCode?
For more information, see Error Codes for AWS CodeDeploy in the AWS CodeDeploy User Guide.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String?
An accompanying error message.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited