GenericRevisionInfo class

Information about an application revision.

Constructors

GenericRevisionInfo({List<String>? deploymentGroups, String? description, DateTime? firstUsedTime, DateTime? lastUsedTime, DateTime? registerTime})
GenericRevisionInfo.fromJson(Map<String, dynamic> json)
factory

Properties

deploymentGroups → List<String>?
The deployment groups for which this is the current target revision.
final
description → String?
A comment about the revision.
final
firstUsedTime → DateTime?
When the revision was first used by AWS CodeDeploy.
final
hashCode → int
The hash code for this object.
no setterinherited
lastUsedTime → DateTime?
When the revision was last used by AWS CodeDeploy.
final
registerTime → DateTime?
When the revision was registered with AWS CodeDeploy.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited