GetApplicationRevisionOutput class

Represents the output of a GetApplicationRevision operation.

Constructors

GetApplicationRevisionOutput({String? applicationName, RevisionLocation? revision, GenericRevisionInfo? revisionInfo})
GetApplicationRevisionOutput.fromJson(Map<String, dynamic> json)
factory

Properties

applicationName → String?
The name of the application that corresponds to the revision.
final
hashCode → int
The hash code for this object.
no setterinherited
revision → RevisionLocation?
Additional information about the revision, including type and location.
final
revisionInfo → GenericRevisionInfo?
General information about the revision.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited