GetOnPremisesInstanceOutput class

Represents the output of a GetOnPremisesInstance operation.

Constructors

GetOnPremisesInstanceOutput({InstanceInfo? instanceInfo})
GetOnPremisesInstanceOutput.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
instanceInfo → InstanceInfo?
Information about the on-premises instance.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited