GitHubLocation class

Information about the location of application artifacts stored in GitHub.

Constructors

GitHubLocation({String? commitId, String? repository})
GitHubLocation.fromJson(Map<String, dynamic> json)
factory

Properties

commitId → String?
The SHA1 commit ID of the GitHub commit that represents the bundled artifacts for the application revision.
final
hashCode → int
The hash code for this object.
no setterinherited
repository → String?
The GitHub account and repository pair that stores a reference to the commit that represents the bundled artifacts for the application revision.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited