InstanceInfo class

Information about an on-premises instance.

Constructors

InstanceInfo({DateTime? deregisterTime, String? iamSessionArn, String? iamUserArn, String? instanceArn, String? instanceName, DateTime? registerTime, List<Tag>? tags})
InstanceInfo.fromJson(Map<String, dynamic> json)
factory

Properties

deregisterTime → DateTime?
If the on-premises instance was deregistered, the time at which the on-premises instance was deregistered.
final
hashCode → int
The hash code for this object.
no setterinherited
iamSessionArn → String?
The ARN of the IAM session associated with the on-premises instance.
final
iamUserArn → String?
The IAM user ARN associated with the on-premises instance.
final
instanceArn → String?
The ARN of the on-premises instance.
final
instanceName → String?
The name of the on-premises instance.
final
registerTime → DateTime?
The time at which the on-premises instance was registered.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<Tag>?
The tags currently associated with the on-premises instance.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited