InstanceSummary class

Information about an instance in a deployment.

Annotations

Constructors

InstanceSummary({String? deploymentId, String? instanceId, InstanceType? instanceType, DateTime? lastUpdatedAt, List<LifecycleEvent>? lifecycleEvents, InstanceStatus? status})
InstanceSummary.fromJson(Map<String, dynamic> json)
factory

Properties

deploymentId → String?
The unique ID of a deployment.
final
hashCode → int
The hash code for this object.
no setterinherited
instanceId → String?
The instance ID.
final
instanceType → InstanceType?
Information about which environment an instance belongs to in a blue/green deployment.
final
lastUpdatedAt → DateTime?
A timestamp that indicates when the instance information was last updated.
final
lifecycleEvents → List<LifecycleEvent>?
A list of lifecycle events for this instance.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → InstanceStatus?
The deployment status for this instance:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited