LambdaTarget class

Information about the target AWS Lambda function during an AWS Lambda deployment.

Constructors

LambdaTarget({String? deploymentId, LambdaFunctionInfo? lambdaFunctionInfo, DateTime? lastUpdatedAt, List<LifecycleEvent>? lifecycleEvents, TargetStatus? status, String? targetArn, String? targetId})
LambdaTarget.fromJson(Map<String, dynamic> json)
factory

Properties

deploymentId → String?
The unique ID of a deployment.
final
hashCode → int
The hash code for this object.
no setterinherited
lambdaFunctionInfo → LambdaFunctionInfo?
A LambdaFunctionInfo object that describes a target Lambda function.
final
lastUpdatedAt → DateTime?
The date and time when the target Lambda function was updated by a deployment.
final
lifecycleEvents → List<LifecycleEvent>?
The lifecycle events of the deployment to this target Lambda function.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → TargetStatus?
The status an AWS Lambda deployment's target Lambda function.
final
targetArn → String?
The Amazon Resource Name (ARN) of the target.
final
targetId → String?
The unique ID of a deployment target that has a type of lambdaTarget.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited