LastDeploymentInfo class

Information about the most recent attempted or successful deployment to a deployment group.

Constructors

LastDeploymentInfo({DateTime? createTime, String? deploymentId, DateTime? endTime, DeploymentStatus? status})
LastDeploymentInfo.fromJson(Map<String, dynamic> json)
factory

Properties

createTime → DateTime?
A timestamp that indicates when the most recent deployment to the deployment group started.
final
deploymentId → String?
The unique ID of a deployment.
final
endTime → DateTime?
A timestamp that indicates when the most recent deployment to the deployment group was complete.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → DeploymentStatus?
The status of the most recent deployment.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited