LifecycleEvent class

Information about a deployment lifecycle event.

Constructors

LifecycleEvent({Diagnostics? diagnostics, DateTime? endTime, String? lifecycleEventName, DateTime? startTime, LifecycleEventStatus? status})
LifecycleEvent.fromJson(Map<String, dynamic> json)
factory

Properties

diagnostics → Diagnostics?
Diagnostic information about the deployment lifecycle event.
final
endTime → DateTime?
A timestamp that indicates when the deployment lifecycle event ended.
final
hashCode → int
The hash code for this object.
no setterinherited
lifecycleEventName → String?
The deployment lifecycle event name, such as ApplicationStop, BeforeInstall, AfterInstall, ApplicationStart, or ValidateService.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → DateTime?
A timestamp that indicates when the deployment lifecycle event started.
final
status → LifecycleEventStatus?
The deployment lifecycle event status:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited