ListApplicationRevisionsOutput class

Represents the output of a ListApplicationRevisions operation.

Constructors

ListApplicationRevisionsOutput({String? nextToken, List<RevisionLocation>? revisions})
ListApplicationRevisionsOutput.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
If a large amount of information is returned, an identifier is also returned. It can be used in a subsequent list application revisions call to return the next set of application revisions in the list.
final
revisions → List<RevisionLocation>?
A list of locations that contain the matching revisions.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited