ListApplicationsOutput class

Represents the output of a ListApplications operation.

Constructors

ListApplicationsOutput({List<String>? applications, String? nextToken})
ListApplicationsOutput.fromJson(Map<String, dynamic> json)
factory

Properties

applications → List<String>?
A list of application names.
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
If a large amount of information is returned, an identifier is also returned. It can be used in a subsequent list applications call to return the next set of applications in the list.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited