ListGitHubAccountTokenNamesOutput class

Represents the output of a ListGitHubAccountTokenNames operation.

Constructors

ListGitHubAccountTokenNamesOutput({String? nextToken, List<String>? tokenNameList})
ListGitHubAccountTokenNamesOutput.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
If a large amount of information is returned, an identifier is also returned. It can be used in a subsequent ListGitHubAccountTokenNames call to return the next set of names in the list.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tokenNameList → List<String>?
A list of names of connections to GitHub accounts.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited