LoadBalancerInfo class

Information about the Elastic Load Balancing load balancer or target group used in a deployment.

Constructors

LoadBalancerInfo({List<ELBInfo>? elbInfoList, List<TargetGroupInfo>? targetGroupInfoList, List<TargetGroupPairInfo>? targetGroupPairInfoList})
LoadBalancerInfo.fromJson(Map<String, dynamic> json)
factory

Properties

elbInfoList → List<ELBInfo>?
An array that contains information about the load balancer to use for load balancing in a deployment. In Elastic Load Balancing, load balancers are used with Classic Load Balancers.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetGroupInfoList → List<TargetGroupInfo>?
An array that contains information about the target group to use for load balancing in a deployment. In Elastic Load Balancing, target groups are used with Application Load Balancers.
final
targetGroupPairInfoList → List<TargetGroupPairInfo>?
The target group pair information. This is an array of TargeGroupPairInfo objects with a maximum size of one.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited