MinimumHealthyHosts class

Information about minimum healthy instance.

Constructors

MinimumHealthyHosts({MinimumHealthyHostsType? type, int? value})
MinimumHealthyHosts.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → MinimumHealthyHostsType?
The minimum healthy instance type:
final
value → int?
The minimum healthy instance value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited