RevisionLocation class

Information about the location of an application revision.

Constructors

RevisionLocation({AppSpecContent? appSpecContent, GitHubLocation? gitHubLocation, RevisionLocationType? revisionType, S3Location? s3Location, RawString? string})
RevisionLocation.fromJson(Map<String, dynamic> json)
factory

Properties

appSpecContent → AppSpecContent?
The content of an AppSpec file for an AWS Lambda or Amazon ECS deployment. The content is formatted as JSON or YAML and stored as a RawString.
final
gitHubLocation → GitHubLocation?
Information about the location of application artifacts stored in GitHub.
final
hashCode → int
The hash code for this object.
no setterinherited
revisionType → RevisionLocationType?
The type of application revision:
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3Location → S3Location?
Information about the location of a revision stored in Amazon S3.
final
string → RawString?
Information about the location of an AWS Lambda deployment revision stored as a RawString.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited