RollbackInfo class

Information about a deployment rollback.

Constructors

RollbackInfo({String? rollbackDeploymentId, String? rollbackMessage, String? rollbackTriggeringDeploymentId})
RollbackInfo.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
rollbackDeploymentId → String?
The ID of the deployment rollback.
final
rollbackMessage → String?
Information that describes the status of a deployment rollback (for example, whether the deployment can't be rolled back, is in progress, failed, or succeeded).
final
rollbackTriggeringDeploymentId → String?
The deployment ID of the deployment that was underway and triggered a rollback deployment because it failed or was stopped.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited