S3Location class

Information about the location of application artifacts stored in Amazon S3.

Constructors

S3Location({String? bucket, BundleType? bundleType, String? eTag, String? key, String? version})
S3Location.fromJson(Map<String, dynamic> json)
factory

Properties

bucket → String?
The name of the Amazon S3 bucket where the application revision is stored.
final
bundleType → BundleType?
The file type of the application revision. Must be one of the following:
final
eTag → String?
The ETag of the Amazon S3 object that represents the bundled artifacts for the application revision.
final
hashCode → int
The hash code for this object.
no setterinherited
key → String?
The name of the Amazon S3 object that represents the bundled artifacts for the application revision.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String?
A specific version of the Amazon S3 object that represents the bundled artifacts for the application revision.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited