StopDeploymentOutput class

Represents the output of a StopDeployment operation.

Constructors

StopDeploymentOutput({StopStatus? status, String? statusMessage})
StopDeploymentOutput.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → StopStatus?
The status of the stop deployment operation:
final
statusMessage → String?
An accompanying status message.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited