TargetInstances class

Information about the instances to be used in the replacement environment in a blue/green deployment.

Constructors

TargetInstances({List<String>? autoScalingGroups, EC2TagSet? ec2TagSet, List<EC2TagFilter>? tagFilters})
TargetInstances.fromJson(Map<String, dynamic> json)
factory

Properties

autoScalingGroups → List<String>?
The names of one or more Auto Scaling groups to identify a replacement environment for a blue/green deployment.
final
ec2TagSet → EC2TagSet?
Information about the groups of EC2 instance tags that an instance must be identified by in order for it to be included in the replacement environment for a blue/green deployment. Cannot be used in the same call as tagFilters.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tagFilters → List<EC2TagFilter>?
The tag filter key, type, and value used to identify Amazon EC2 instances in a replacement environment for a blue/green deployment. Cannot be used in the same call as ec2TagSet.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited