TriggerConfig class

Information about notification triggers for the deployment group.

Constructors

TriggerConfig({List<TriggerEventType>? triggerEvents, String? triggerName, String? triggerTargetArn})
TriggerConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
triggerEvents → List<TriggerEventType>?
The event type or types for which notifications are triggered.
final
triggerName → String?
The name of the notification trigger.
final
triggerTargetArn → String?
The Amazon Resource Name (ARN) of the Amazon Simple Notification Service topic through which notifications about deployment or instance events are sent.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited